require 'test_helper'

class EmailFormatValidatorTest < ActiveSupport::TestCase
  test "tld length" do
    obj = EmailValidatable.new

    obj.email = "me@no.yes.x"
    refute obj.valid?, 'allowed single length tld'

    obj.email = "me@no.yes.co"
    assert obj.valid?, 'did not allow tld length 2'

    obj.email = "me@no.yes.com"
    assert obj.valid?, 'did not allow tld length 3'

    obj.email = "me@no.yes.commets"
    assert obj.valid?, 'did not allow tld length > 3'
  end

  test "can handle comma seperated addresses" do
    obj = EmailValidatable.new
    obj.email = "me@no.yes, me@yes.no"

    assert obj.valid?, 'did not allow multiple address [comma seperated]'
  end

  test "provides proper error message" do
    obj = EmailValidatable.new
    obj.email = "this is a bad email address"
    obj.valid?

    refute obj.errors.messages.empty?, 'needs an error message'
    assert_match(/not formatted properly/, obj.errors.messages[:email].join)
  end
end
